Software to process X-ray Emission Spectroscopy data at APS Sector 20.

Note the initial checkin of this software is from the working version used at Sector 20 on March 20, 2019. This code was written by Brian Mattern while he was a graduate student in Gerald Seidler's group at the University of Washington.

At this point, the beamline at Sector 20 is using a Pilatus 100k detector and 10 analyzer crystals in a single row.  The spectroscopy group is working on improving the experiment.  They will be adding a Pilatus 2M detector (already purchased and in house) and increase the crystals to a n x m array of analyzers.  This will increase the data throughput of the instrument by allowing for more simultaneous measurements of the energy spectrum.
The original source code has been modified by the John Hammonds (JPHammonds@anl.gov) in the Scientific Software Engineering and Data Management Group in the X-Ray Science Division at the Advanced Photon Source at Argonne National Laboratory.  These changes are to accomodate the changes mentioned above to the Crystal Analyzer and Detector.  The file CHANGES.md captures information about major changes to the code from the original version. 
